@@ -20,4 +20,9 @@ class Equality:
         self.__kwds = kwds
 
     def __call__(self, args, kwds):
-        return self.__args == args and self.__kwds == kwds
+        # @todo Test this optimization (it avoids calling __eq__, which is good for example when expecting... a mock.object)
+        return (
+            kwds == self.__kwds
+            and len(args) == len(self.__args)
+            and all((a is b or a == b) for (a, b) in zip(args, self.__args))
+        )
