@@ -26,3 +26,7 @@ class Mock(object):
     @property
     def object(self):
         return self.__handler.object(self.__name)
+
+    def record(self, realObject):
+        # @todo In record mode, catch exceptions. Funny: there is not always a "return" key in getRecordedCalls
+        return self.__handler.record(self.__name, realObject)
