@@ -15,6 +15,4 @@
 
 
 class MockException(Exception):
-    def __init__(self, message):
-        Exception.__init__(self)
-        self.message = message
+    pass
