@@ -37,11 +37,11 @@ class PublicInterface(unittest.TestCase):
         self.assertEqual(self.dir(MockMockMock), ["Engine", "Exception", "tests"])
 
     def testEngine(self):
-        self.assertEqual(self.dir(self.mocks), ["alternative", "atomic", "create", "optional", "ordered", "repeated", "replace", "tearDown", "unordered"])
+        self.assertEqual(self.dir(self.mocks), ["alternative", "atomic", "create", "optional", "ordered", "records", "repeated", "replace", "tearDown", "unordered"])
         self.assertFalse(isCallable(self.mocks))
 
     def testMock(self):
-        self.assertEqual(self.dir(self.myMock), ["expect", "object"])
+        self.assertEqual(self.dir(self.myMock), ["expect", "object", "record"])
         self.assertFalse(isCallable(self.myMock))
 
     def testExpect(self):
@@ -75,7 +75,7 @@ class PublicInterface(unittest.TestCase):
         self.assertFalse(isCallable(self.myMock.expect.foobar.andExecute(lambda: 12)))
 
     def testObject(self):
-        ### @todo Maybe expose expected calls in myMock.object.__dir__
+        # @todo Maybe expose expected calls in myMock.object.__dir__
         self.assertEqual(self.dir(self.myMock.object), [])
 
     def dir(self, o):
